@@ -538,9 +538,13 @@ class Template(MarkupTemplate):
                 grand_parent = parent.getparent()
                 # Guess type only if it is the only value in the cell
                 # and its parent has no style
-                if (grand_parent is None
-                        or grand_parent.tag != table_cell_tag
-                        ) or len(grand_parent) != 1 or has_style(parent):
+                if ((grand_parent is None
+                            or grand_parent.tag != table_cell_tag)
+                        or len(grand_parent) != 1
+                        or len(parent) != 1
+                        or (parent.text and parent.text.strip())
+                        or (r_node.tail and r_node.tail.strip())
+                        or has_style(parent)):
                     r_node.attrib[py_replace] = (
                         '__relatorio_escape_invalid_chars(%s)' % expr)
                     continue
@@ -949,7 +953,11 @@ def extract_images(child, namespaces, start=0):
         binary_data, = image.xpath(
             './office:binary-data', namespaces=namespaces)
         data = base64.b64decode(binary_data.text)
-        mime_type = magic.from_buffer(data, mime=True)
+        if hasattr(magic, 'from_buffer'):
+            mime_type = magic.from_buffer(data, mime=True)
+        else:
+            # Not python-magic but file-magic
+            mime_type = magic.detect_from_content(data).mime_type
         name = 'Pictures/image%s%s' % (
             i, mimetypes.guess_extension(mime_type))
         image.remove(binary_data)
@@ -1070,7 +1078,7 @@ if sys.version_info >= (3, 6):
             self._zinfo = None
 
         def open(self, zinfo):
-            if self._fp:
+            if self._fp or self._buffer:
                 self.close()
             self._zinfo = zinfo
             self._fp = None
